a data frame containing the win odds and its confidence interval. It contains the following columns:
WO calculated win odds.
LCL lower confidence limit.
UCL upper confidence limit.
SE standard error of the win odds.
WOnull win odds of the null hypothesis (specified in the WOnull argument).
alpha two-sided significance level for calculating the confidence interval (specified in the alpha argument).
Pvalue p-value associated with testing the null hypothesis.
WP calculated win probability.
WP_SE standard error of the win probability.
WP_SD standard deviation of the win probability, calculated as WP_SE multiplied by sqrt(N).
N total number of patients in the analysis.
formula returning the specified formula in the x argument.
ref showing how the reference group was selected. Can be modifying by specifying the ref argument.