deltaWO: A generic function for calculating win odds based on a...

deltaWOR Documentation

A generic function for calculating win odds based on a threshold

Description

A generic function for calculating win odds based on a threshold

Usage

deltaWO(x, delta, ...)

Arguments

x

an object used to select a method.

delta

a numeric threshold.

...

further arguments passed to or from other methods.

Value

a data frame containing calculated values.

See Also

deltaWO.adhce() method.


hce documentation built on March 13, 2026, 1:06 a.m.