Learn R Programming

hce (version 0.9.0)

deltaWO: A generic function for calculating win odds based on a threshold

Description

A generic function for calculating win odds based on a threshold

Usage

deltaWO(x, delta, ...)

Value

a data frame containing calculated values.

Arguments

x

an object used to select a method.

delta

a numeric threshold.

...

further arguments passed to or from other methods.

See Also

deltaWO.adhce() method.