Learn R Programming

hce (version 0.9.0)

deltaWO.adhce: Win odds calculation based on a threshold for adhce objects

Description

Win odds calculation based on a threshold for adhce objects

Usage

# S3 method for adhce
deltaWO(x, delta, ref = unique(x$TRTP)[1], alpha = 0.05, WOnull = 1, ...)

Value

a data frame containing the win odds and its confidence interval. It contains the following columns:

  • WO calculated win odds.

  • LCL lower confidence limit.

  • UCL upper confidence limit.

  • SE standard error of the win odds.

  • WOnull win odds of the null hypothesis (specified in the WOnull argument).

  • alpha two-sided significance level for calculating the confidence interval (specified in the alpha argument).

  • Pvalue p-value associated with testing the null hypothesis.

  • WP calculated win probability.

  • LCL_WP lower confidence limit for WP.

  • UCL_WP upper confidence limit for WP.

  • SE_WP standard error of the win probability.

  • SD_WP standard deviation of the win probability, calculated as SE_WP multiplied by sqrt(N).

  • N total number of patients in the analysis.

  • ref the reference group.

  • delta the threshold.

Arguments

x

an adhce object.

delta

a numeric threshold.

ref

the reference treatment group.

alpha

significance level. The default is 0.05.

WOnull

the null hypothesis. The default is 1.

...

additional parameters.

See Also

deltaWO(), calcWO().

Examples

Run this code
# Example using the kidney dataset
dat <- as_hce(KHCE)
calcWO(dat, ref = "P")
## The exact same result
deltaWO(dat, delta = 0, ref = "P")
## A large threshold
deltaWO(dat, delta = 10, ref = "P")

Run the code above in your browser using DataLab